@@ -44,6 +44,7 @@
 #include "hildon-file-system-local-device.h"
 #include "hildon-file-system-mmc.h"
 #include "hildon-file-system-upnp.h"
+#include "hildon-file-system-smb.h"
 #include "hildon-file-system-obex.h"
 #include "hildon-file-system-old-gateway.h"
 
@@ -51,11 +52,15 @@ extern GtkFileSystem *gtk_file_system_unix_new();
 
 /* Let's make sure that we survise with folder names both ending and
  * not ending to slash */
-gboolean _hildon_file_system_compare_ignore_last_separator(const char *a,
-                                                           const char *b)
+gboolean
+_hildon_file_system_compare_ignore_last_separator(const char *a,
+						  const char *b)
 {        
     gint len_a, len_b;
 
+    if (a == NULL || b == NULL)
+      return FALSE;
+
     /* XXX - Canonicalize the "file://" prefix away since not all path
              strings use it uniformly.  We should really be using the
              GtkFileSystem path manipulation API religiously instead
@@ -217,6 +222,14 @@ GNode *_hildon_file_system_get_locations(GtkFileSystem *fs)
                 g_node_append_data(locations, location);
             }    
         }
+
+	/* Setup SMB
+	 */
+	{
+	  location = g_object_new (HILDON_TYPE_FILE_SYSTEM_SMB, NULL);
+	  location->basepath = g_strdup ("smb://");
+	  g_node_append_data (locations, location);
+	}
     }
 
     return locations;
@@ -257,7 +270,7 @@ static gboolean get_special_location_callback(GNode *node, gpointer data)
                     candidate->basepath, searched->uri, (gpointer) searched->result);
             }
 
-            return searched->result != NULL;
+	    return searched->result != NULL;
         }
     }
 
